pub fn startup_repl(
profile: &str,
prompt: Option<&str>,
) -> (ReplSession, ReplStartupContract)Expand description
Startup REPL session using the same policy precedence and routing registry as CLI.
pub fn startup_repl(
profile: &str,
prompt: Option<&str>,
) -> (ReplSession, ReplStartupContract)Startup REPL session using the same policy precedence and routing registry as CLI.