Module runtime

Module runtime 

Runtime execution entrypoints.

Structs

AppRunResult
In-memory process output and exit result produced by the core app runner.

Functions

run_app
Execute the CLI for provided argv and return output streams and exit code.
run_cli_from_env
Execute the CLI process using current OS argv.