pub fn run_app(argv: &[String]) -> Result<AppRunResult>Expand description
Execute the CLI for provided argv and return output streams and exit code.
pub fn run_app(argv: &[String]) -> Result<AppRunResult>Execute the CLI for provided argv and return output streams and exit code.