pub struct ProductEntrypoint {
pub kind: ProductEntrypointKind,
pub command: String,
pub module: Option<String>,
pub function: Option<String>,
}Fields
kind: ProductEntrypointKindcommand: Stringmodule: Option<String>function: Option<String>Trait Implementations
Sourceimpl Clone for ProductEntrypoint
impl Clone for ProductEntrypoint
Sourcefn clone(&self) -> ProductEntrypoint
fn clone(&self) -> ProductEntrypoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProductEntrypoint
impl Debug for ProductEntrypoint
Sourceimpl<'de> Deserialize<'de> for ProductEntrypoint
impl<'de> Deserialize<'de> for ProductEntrypoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProductEntrypoint
Sourceimpl JsonSchema for ProductEntrypoint
impl JsonSchema for ProductEntrypoint
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProductEntrypoint
impl PartialEq for ProductEntrypoint
Sourceimpl Serialize for ProductEntrypoint
impl Serialize for ProductEntrypoint
impl StructuralPartialEq for ProductEntrypoint