pub struct CommandContext {
pub cwd: PathBuf,
pub project_root: Option<PathBuf>,
pub config_dirs: Vec<PathBuf>,
pub output_format: OutputFormat,
pub pretty_mode: PrettyMode,
pub color_mode: ColorMode,
pub verbosity: LogLevel,
pub quiet: bool,
pub invocation_id: String,
pub parent_command: CommandPath,
}Expand description
Execution context passed to mounted app handlers.
Fields
cwd: PathBufproject_root: Option<PathBuf>config_dirs: Vec<PathBuf>output_format: OutputFormatpretty_mode: PrettyModecolor_mode: ColorModeverbosity: LogLevelquiet: boolinvocation_id: Stringparent_command: CommandPathImplementations
Sourceimpl CommandContext
impl CommandContext
Sourcepub fn builder(parent_command: CommandPath) -> CommandContextBuilder
pub fn builder(parent_command: CommandPath) -> CommandContextBuilder
Start a builder from the required parent command path.
Sourcepub fn command_path(
&self,
tail_segments: &[&str],
) -> Result<CommandPath, String>
pub fn command_path( &self, tail_segments: &[&str], ) -> Result<CommandPath, String>
Build a child command path below the mounted app command root.