pub struct RenderedCommandResult {
pub exit_code: ExitCode,
pub stdout: String,
pub stderr: String,
}Expand description
Rendered command result returned by the SDK harness.
Fields
exit_code: ExitCodestdout: Stringstderr: StringTrait Implementations
Sourceimpl Clone for RenderedCommandResult
impl Clone for RenderedCommandResult
Sourcefn clone(&self) -> RenderedCommandResult
fn clone(&self) -> RenderedCommandResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderedCommandResult
impl Debug for RenderedCommandResult
Sourceimpl<'de> Deserialize<'de> for RenderedCommandResult
impl<'de> Deserialize<'de> for RenderedCommandResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RenderedCommandResult
Sourceimpl JsonSchema for RenderedCommandResult
impl JsonSchema for RenderedCommandResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RenderedCommandResult
impl PartialEq for RenderedCommandResult
Sourceimpl Serialize for RenderedCommandResult
impl Serialize for RenderedCommandResult
impl StructuralPartialEq for RenderedCommandResult