pub struct SdkRenderConfig {
pub format: OutputFormat,
pub pretty_mode: PrettyMode,
pub color_mode: ColorMode,
pub verbosity: LogLevel,
pub quiet: bool,
pub no_color: bool,
}Expand description
Public render configuration for mounted-app command results.
Fields
format: OutputFormatpretty_mode: PrettyModecolor_mode: ColorModeverbosity: LogLevelquiet: boolno_color: boolTrait Implementations
Sourceimpl Clone for SdkRenderConfig
impl Clone for SdkRenderConfig
Sourcefn clone(&self) -> SdkRenderConfig
fn clone(&self) -> SdkRenderConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SdkRenderConfig
Sourceimpl Debug for SdkRenderConfig
impl Debug for SdkRenderConfig
Sourceimpl Default for SdkRenderConfig
impl Default for SdkRenderConfig
Sourceimpl<'de> Deserialize<'de> for SdkRenderConfig
impl<'de> Deserialize<'de> for SdkRenderConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SdkRenderConfig
Sourceimpl From<SdkRenderConfig> for EmitterConfig
impl From<SdkRenderConfig> for EmitterConfig
Sourcefn from(value: SdkRenderConfig) -> Self
fn from(value: SdkRenderConfig) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for SdkRenderConfig
impl JsonSchema for SdkRenderConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SdkRenderConfig
impl PartialEq for SdkRenderConfig
Sourceimpl Serialize for SdkRenderConfig
impl Serialize for SdkRenderConfig
impl StructuralPartialEq for SdkRenderConfig