Runtime execution entrypoints.
Structs
- AppRun
Result - In-memory process output and exit result produced by the core app runner.
Functions
- run_app
- Execute the CLI for provided argv and return output streams and exit code.
- run_
cli_ from_ env - Execute the CLI process using current OS argv.